@@ -37,22 +37,14 @@ impl Mount {
     pub fn is_unreachable(&self) -> bool {
         matches!(self.stats, Err(StatsError::Unreachable))
     }
-}
 
-#[derive(Debug, Clone)]
-pub struct ReadOptions {
-    pub(crate) remote_stats: bool,
-}
-impl Default for ReadOptions {
-    fn default() -> Self {
-        Self { remote_stats: true }
+    #[cfg(unix)]
+    pub fn is_remote(&self) -> bool {
+        self.info.is_remote()
     }
-}
-impl ReadOptions {
-    pub fn remote_stats(
-        &mut self,
-        v: bool,
-    ) {
-        self.remote_stats = v;
+
+    #[cfg(windows)]
+    pub fn is_remote(&self) -> bool {
+        self.disk.as_ref().is_some_and(|disk| disk.remote)
     }
 }
